@@ -13,6 +13,6 @@ def main():
 
     subcommand = settings._SUBCOMMAND
 
-    x = importlib.import_module('zymkey.commands.{}'.format(subcommand))
+    x = importlib.import_module("zymkey.commands.{}".format(subcommand))
 
     sys.exit(x.main())
